==> lxqt-admin_0.14.0.orig.tar.gz: lxqt-admin-0.14.0/lxqt-admin-time/translations/lxqt-admin-time_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>DateTime</name>
    <message>
        <location filename="../datetime.ui" line="23"/>
        <source>Time:</source>
        <translation>Hora:</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="39"/>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="53"/>
        <source>Date:</source>
        <translation>Data:</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="70"/>
        <source>Enable network time synchronization (NTP)</source>
        <translation>Ativar sincronização de hora com a rede (NTP)</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="77"/>
        <source>RTC is in local time</source>
        <translation>RTC está na hora local</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../fbsdtimedatectl.cpp" line="122"/>
        <source>lxqt-admin-time-helper</source>
        <translation>lxqt-admin-time-helper</translation>
    </message>
    <message>
        <location filename="../fbsdtimedatectl.cpp" line="123"/>
        <source>&lt;strong&gt;Action (%1) failed:&lt;/strong&gt;&lt;br/&gt;&lt;pre&gt;%2&lt;/pre&gt;</source>
        <translation>&lt;strong&gt;A ação (%1) falhou:&lt;/strong&gt;&lt;br/&gt;&lt;pre&gt;%2&lt;/pre&gt;</translation>
    </message>
</context>
<context>
    <name>TimeAdminDialog</name>
    <message>
        <location filename="../timeadmindialog.cpp" line="45"/>
        <source>Time and date configuration</source>
        <translation>Configuração de data e hora</translation>
    </message>
    <message>
        <location filename="../timeadmindialog.cpp" line="51"/>
        <source>Date and time</source>
        <translation>Data e hora</translation>
    </message>
    <message>
        <location filename="../timeadmindialog.cpp" line="59"/>
        <source>Timezone</source>
        <translation>Fuso horário</translation>
    </message>
    <message>
        <location filename="../timeadmindialog.cpp" line="120"/>
        <location filename="../timeadmindialog.cpp" line="130"/>
        <location filename="../timeadmindialog.cpp" line="137"/>
        <location filename="../timeadmindialog.cpp" line="147"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../timeadmindialog.cpp" line="154"/>
        <source>Change RTC to be in localtime requires a reboot</source>
        <translation>Tem que reiniciar para alterar de RTC para hora local</translation>
    </message>
    <message>
        <location filename="../timeadmindialog.cpp" line="154"/>
        <source>Change RTC to be in UTC requires a reboot</source>
        <translation>Tem que reiniciar para alterar de RTC para UTC</translation>
    </message>
    <message>
        <location filename="../timeadmindialog.cpp" line="155"/>
        <source>Reboot required</source>
        <translation>Tem que reiniciar</translation>
    </message>
</context>
<context>
    <name>Timezone</name>
    <message>
        <location filename="../timezone.ui" line="19"/>
        <source>Your current timezone:</source>
        <translation>O fuso horário atual:</translation>
    </message>
    <message>
        <location filename="../timezone.ui" line="32"/>
        <source>Filter</source>
        <translation>Filtrar</translation>
    </message>
</context>
<context>
    <name>TimezonePage</name>
    <message>
        <location filename="../timezone.cpp" line="42"/>
        <source>None</source>
        <translation>Nenhum</translation>
    </message>
</context>
</TS>

==> lxqt-admin_2.1.0.orig.tar.gz: lxqt-admin-2.1.0/lxqt-admin-time/translations/lxqt-admin-time_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>DateTime</name>
    <message>
        <location filename="../datetime.ui" line="23"/>
        <source>Time:</source>
        <translation>Hora:</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="39"/>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="53"/>
        <source>Date:</source>
        <translation>Data:</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="70"/>
        <source>Enable network time synchronization (NTP)</source>
        <translation>Ativar sincronização de hora com a rede (NTP)</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="77"/>
        <source>RTC is in local time</source>
        <translation>RTC está na hora local</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../nosdtimedatectl.cpp" line="144"/>
        <source>lxqt-admin-time-helper</source>
        <translation>lxqt-admin-time-helper</translation>
    </message>
    <message>
        <location filename="../fbsdtimedatectl.cpp" line="123"/>
        <location filename="../nosdtimedatectl.cpp" line="145"/>
        <source>&lt;strong&gt;Action (%1) failed:&lt;/strong&gt;&lt;br/&gt;&lt;pre&gt;%2&lt;/pre&gt;</source>
        <translation>&lt;strong&gt;Ação (%1) falhou:&lt;/strong&gt;&lt;br/&gt;&lt;pre&gt;%2&lt;/pre&gt;</translation>
    </message>
</context>
<context>
    <name>TimeAdminDialog</name>
    <message>
        <location filename="../timeadmindialog.cpp" line="46"/>
        <source>Time and date configuration</source>
        <translation>Configuração de data e hora</translation>
    </message>
    <message>
        <location filename="../timeadmindialog.cpp" line="52"/>
        <source>Date and time</source>
        <translation>Data e hora</translation>
    </message>
    <message>
        <location filename="../timeadmindialog.cpp" line="60"/>
        <source>Timezone</source>
        <translation>Fuso horário</translation>
    </message>
    <message>
        <location filename="../timeadmindialog.cpp" line="123"/>
        <location filename="../timeadmindialog.cpp" line="133"/>
        <location filename="../timeadmindialog.cpp" line="140"/>
        <location filename="../timeadmindialog.cpp" line="150"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../timeadmindialog.cpp" line="157"/>
        <source>Change RTC to be in localtime requires a reboot</source>
        <translation>Tem que reiniciar para alterar de RTC para hora local</translation>
    </message>
    <message>
        <location filename="../timeadmindialog.cpp" line="157"/>
        <source>Change RTC to be in UTC requires a reboot</source>
        <translation>Tem que reiniciar para alterar de RTC para UTC</translation>
    </message>
    <message>
        <location filename="../timeadmindialog.cpp" line="158"/>
        <source>Reboot required</source>
        <translation>Tem que reiniciar</translation>
    </message>
</context>
<context>
    <name>Timezone</name>
    <message>
        <location filename="../timezone.ui" line="19"/>
        <source>Your current timezone:</source>
        <translation>O fuso horário atual:</translation>
    </message>
    <message>
        <location filename="../timezone.ui" line="32"/>
        <source>Filter</source>
        <translation>Filtrar</translation>
    </message>
</context>
<context>
    <name>TimezonePage</name>
    <message>
        <location filename="../timezone.cpp" line="42"/>
        <source>None</source>
        <translation>Nenhum</translation>
    </message>
</context>
</TS>
